/**
 * Copyright (C) 2023 Chris Noxz
 * Author(s): Chris Noxz <chris@noxz.tech>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

static Config cfg[LastConfig] = {
	/* config name              enviornment variable name                       config type       default value */
	[AcceptedLanguages]     = { __NAME_UPPERCASE__"_ACCEPTED_LANGUAGES",        CFG_LIST,   {.l = NULL }},
	[BadTlsTabFormat]       = { NULL,                                           CFG_STRING, {.s = "<span foreground=\"yellow\" style=\"italic\">%s</span>" }},
	[ConsoleToStdout]       = { __NAME_UPPERCASE__"_ENABLE_CONSOLE_TO_STDOUT",  CFG_BOOL,   {.b = FALSE }},
	[CookieFile]            = { __NAME_UPPERCASE__"_COOKIE_FILE",               CFG_STRING, {.s = NULL }},
	[DefaultFont]           = { __NAME_UPPERCASE__"_DEFAULT_FONT",              CFG_STRING, {.s = "monospace" }},
	[DefaultFontSize]       = { __NAME_UPPERCASE__"_DEFAULT_FONT_SIZE",         CFG_INT,    {.i = 12 }},
	[DownloadDirectory]     = { __NAME_UPPERCASE__"_DOWNLOAD_DIR",              CFG_STRING, {.s = "/var/tmp" }},
	[DeveloperExtras]       = { NULL,                                           CFG_BOOL,   {.b = TRUE }},
	[ExternalHandlerFile]   = { NULL,                                           CFG_STRING, {.s = "exthandler" }},
	[FifoName]              = { __NAME_UPPERCASE__"_FIFO_NAME",                 CFG_STRING, {.s = "default" }},
	[HistoryFile]           = { __NAME_UPPERCASE__"_HISTORY_FILE",              CFG_STRING, {.s = NULL }},
	[HomeUri]               = { __NAME_UPPERCASE__"_HOME_URI",                  CFG_STRING, {.s = "about:blank" }},
	[DisableAutoLoadImages] = { __NAME_UPPERCASE__"_DISABLE_AUTO_LOAD_IMAGES",  CFG_BOOL,   {.b = FALSE }},
	[MonospaceFont]         = { __NAME_UPPERCASE__"_MONOSPACE_FONT",            CFG_STRING, {.s = "monospace" }},
	[NormalTabFormat]       = { NULL,                                           CFG_STRING, {.s = "<span>%s</span>" }},
	[ProxyIgnore]           = { __NAME_UPPERCASE__"_PROXY_IGNORE",              CFG_LIST,   {.l = NULL }},
	[ProxyUri]              = { __NAME_UPPERCASE__"_PROXY_URI",                 CFG_STRING, {.s = NULL }},
	[SansSerifFont]         = { __NAME_UPPERCASE__"_SANS_SERIF_FONT",           CFG_STRING, {.s = "sans-serif" }},
	[SearchEngineUriFormat] = { __NAME_UPPERCASE__"_SE_URI_FORMAT",             CFG_STRING, {.s = "https://ddg.gg?q=%s" }},
	[SerifFont]             = { __NAME_UPPERCASE__"_SERIF_FONT",                CFG_STRING, {.s = "serif" }},
	[SmoothScrolling]       = { __NAME_UPPERCASE__"_ENABLE_SMOOTH_SCROLLING",   CFG_BOOL,   {.b = FALSE }},
	[StateFile]             = { __NAME_UPPERCASE__"_STATE_FILE",                CFG_STRING, {.s = NULL }},
	[UriSchemes]            = { NULL,                                           CFG_LIST,   {.l = (gchar*[]){ "http", "https", "file", "about", "data", "webkit", NULL } }},
	[UserAgent]             = { __NAME_UPPERCASE__"_USER_AGENT",                CFG_STRING, {.s = NULL }},
	[UsDir]                 = { NULL,                                           CFG_STRING, {.s = "scripts" }},
	[UcDir]                 = { NULL,                                           CFG_STRING, {.s = "styles" }},
	[WeDir]                 = { NULL,                                           CFG_STRING, {.s = "web_extensions" }},
	[ZoomLevel]             = { __NAME_UPPERCASE__"_ZOOM_LEVEL",                CFG_FLOAT,  {.f = 1.0 }},
};

#endif /* !CONFIG_H */
